Numeric patterns
========================

Numeric Arrays
---------------------------
.. autoclass:: paragami.numeric_array_patterns.NumericArrayPattern
   :members:


Symmetric Positive Definite Matrices
----------------------------------------

.. autoclass:: paragami.psdmatrix_patterns.PSDSymmetricMatrixPattern
   :members:

Simplexes
---------------------------

.. autoclass:: paragami.simplex_patterns.SimplexArrayPattern
  :members:
